@@ -57,6 +57,9 @@ no_spans_df <- data.frame(
 #' @param spanning_col_labels (`data.frame`)\cr A data.frame with the columns
 #'   `span_level`, `label`, `start`, and `span` defining 0 or more levels of
 #'   addition spanning (ie grouping) of columns. Defaults to no additional spanning labels.
+#' @param round_type (`string`)\cr the type of rounding to perform.
+#' Allowed values are (`"iec"` (default), `"iec_mod"` or `"sas"`).
+#' \cr See [formatters::format_value()] for details.
 #'
 #' @return A `listing_df` object, sorted by its key columns.
 #'
@@ -180,7 +183,9 @@ as_listing <- function(df,
                        main_footer = NULL,
                        prov_footer = NULL,
                        split_into_pages_by_var = NULL,
-                       spanning_col_labels = no_spans_df) {
+                       spanning_col_labels = no_spans_df,
+                       round_type = valid_round_type) {
+  round_type <- match.arg(round_type)
   checkmate::assert_multi_class(add_trailing_sep, c("character", "numeric"), null.ok = TRUE)
   checkmate::assert_string(trailing_sep, n.chars = 1)
 
@@ -300,6 +305,7 @@ as_listing <- function(df,
   prov_footer(df) <- prov_footer
   listing_dispcols(df) <- cols
   spanning_col_label_df(df) <- spanning_col_labels
+  obj_round_type(df) <- round_type
 
   if (!is.null(split_into_pages_by_var)) {
     df <- split_into_pages_by_var(df, split_into_pages_by_var)
@@ -329,17 +335,16 @@ as_listing <- function(df,
         "The column specified in `add_trailing_sep` does not exist in the dataframe."
       )
     }
-    row_ind_for_trail_sep <- apply(
+    row_ind_for_trail_sep <- which(apply(
       apply(as.data.frame(df_tmp)[, add_trailing_sep, drop = FALSE], 2, function(col_i) {
         diff(as.numeric(as.factor(col_i)))
       }),
       1, function(row_i) any(row_i != 0)
-    ) %>%
-      which()
+    ))
     listing_trailing_sep(df_tmp) <- list(
       "var_trailing_sep" = add_trailing_sep,
       "where_trailing_sep" = row_ind_for_trail_sep,
-      "what_to_separe" = trailing_sep
+      "what_to_separate" = trailing_sep
     )
   } else if (is.numeric(add_trailing_sep)) {
     if (any(!add_trailing_sep %in% seq_len(nrow(df_tmp)))) {
@@ -350,7 +355,7 @@ as_listing <- function(df,
     listing_trailing_sep(df_tmp) <- list(
       "var_trailing_sep" = NULL, # If numeric only
       "where_trailing_sep" = add_trailing_sep,
-      "what_to_separe" = trailing_sep
+      "what_to_separate" = trailing_sep
     )
   }
 
@@ -370,8 +375,9 @@ spanning_col_label_df <- function(df) {
 #' @export
 #' @rdname listings
 `spanning_col_label_df<-` <- function(df, value) {
-  if (is.null(value))
+  if (is.null(value)) {
     value <- no_spans_df
+  }
 
   checkmate::assert_data_frame(value, min.cols = 4, max.cols = 4, col.names = "named")
   checkmate::assert_set_equal(names(value), c("span_level", "label", "start", "span"))
@@ -443,12 +449,17 @@ get_keycols <- function(df) {
 #' @export
 setMethod(
   "matrix_form", "listing_df",
-  rix_form <- function(obj,
-                       indent_rownames = FALSE,
-                       expand_newlines = TRUE,
-                       fontspec = font_spec,
-                       col_gap = 3L,
-                       round_type = c("iec", "sas")) {
+  function(obj,
+           indent_rownames = FALSE,
+           expand_newlines = TRUE,
+           fontspec = font_spec,
+           col_gap = 3L,
+           round_type = obj_round_type(obj)) {
+    new_dev <- open_font_dev(fontspec)
+    if (new_dev) {
+      on.exit(close_font_dev())
+    }
+
     ##  we intentionally silently ignore indent_rownames because listings have
     ## no rownames, but formatters::vert_pag_indices calls matrix_form(obj, TRUE)
     ## unconditionally.
@@ -527,7 +538,7 @@ setMethod(
 
       # We need to make sure that the trailing separator is not beyond the number of rows (cases like head())
       lts$where_trailing_sep <- lts$where_trailing_sep[lts$where_trailing_sep <= nrow(row_info)]
-      row_info$trailing_sep[lts$where_trailing_sep] <- lts$what_to_separe
+      row_info$trailing_sep[lts$where_trailing_sep] <- lts$what_to_separate
     }
 
     span_hdr <- make_span_hdr_mats(spanning_col_label_df(obj), length(listing_dispcols(obj)))
@@ -569,7 +580,8 @@ setMethod(
       prov_footer = prov_footer(obj),
       col_gap = col_gap,
       fontspec = fontspec,
-      rep_cols = length(keycols)
+      rep_cols = length(keycols),
+      round_type = round_type
     )
   }
 )
@@ -673,7 +685,7 @@ listing_trailing_sep <- function(df) attr(df, "listing_trailing_sep") %||% NULL
   }
   checkmate::assert_set_equal(
     names(value),
-    c("var_trailing_sep", "where_trailing_sep", "what_to_separe")
+    c("var_trailing_sep", "where_trailing_sep", "what_to_separate")
   )
   attr(df, "listing_trailing_sep") <- value
   df
@@ -786,8 +798,8 @@ split_into_pages_by_var <- function(lsting, var, page_prefix = var) {
   }
 
   # Correction for cases with trailing separators
-  if (!is.null(listing_trailing_sep(lsting))) {
-    trailing_sep_directives <- listing_trailing_sep(lsting)
+  trailing_sep_directives <- listing_trailing_sep(lsting)
+  if (!is.null(trailing_sep_directives)) {
     if (is.null(trailing_sep_directives$var_trailing_sep)) {
       stop(
         "Current lsting did have add_trailing_sep directives with numeric indexes. ",
@@ -795,7 +807,7 @@ split_into_pages_by_var <- function(lsting, var, page_prefix = var) {
       )
     }
     add_trailing_sep <- trailing_sep_directives$var_trailing_sep
-    trailing_sep <- trailing_sep_directives$trailing_sep
+    trailing_sep <- trailing_sep_directives$what_to_separate
     lsting_by_var <- lapply(lsting_by_var, .do_add_trailing_sep, add_trailing_sep, trailing_sep)
   }
 
