@@ -19,7 +19,7 @@ print.listing_df <- function(x,
                              max_width = NULL,
                              fontspec = NULL,
                              col_gap = 3L,
-                             round_type = c("iec", "sas"),
+                             round_type = obj_round_type(x),
                              ...) {
   tryCatch(
     {
@@ -54,7 +54,7 @@ setMethod("toString", "listing_df", function(x,
                                              widths = NULL,
                                              fontspec = NULL,
                                              col_gap = 3L,
-                                             round_type = c("iec", "sas"),
+                                             round_type = obj_round_type(x),
                                              ...) {
   toString(
     matrix_form(x, fontspec = fontspec, col_gap = col_gap, round_type = round_type),
@@ -81,10 +81,13 @@ basic_run_lens <- function(x) {
 #' @param df (`listing_df`)\cr the listing.
 #' @param colnm (`string`)\cr column name.
 #' @param colvec (`vector`)\cr column values based on `colnm`.
+#' @param round_type (`string`)\cr the type of rounding to perform.
+#' Allowed values are (`"iec"` (default), `"iec_mod"` or `"sas"`).
+#' \cr See [formatters::format_value()] for details.
 #'
 #' @rdname vec_nlines
 #' @keywords internal
-format_colvector <- function(df, colnm, colvec = df[[colnm]], round_type = c("iec", "sas")) {
+format_colvector <- function(df, colnm, colvec = df[[colnm]], round_type = valid_round_type) {
   if (missing(colvec) && !(colnm %in% names(df))) {
     stop("column ", colnm, " not found")
   }
@@ -104,11 +107,14 @@ format_colvector <- function(df, colnm, colvec = df[[colnm]], round_type = c("ie
 #'
 #' @param vec (`vector`)\cr a column vector to be rendered into ASCII.
 #' @param max_width (`numeric(1)` or `NULL`)\cr the width to render the column with.
+#' @param round_type (`string`)\cr the type of rounding to perform.
+#' Allowed values are (`"iec"` (default), `"iec_mod"` or `"sas"`).
+#' \cr See [formatters::format_value()] for details.
 #' @return (`numeric`)\cr a vector of the number of lines element-wise that will be
 #'   needed to render the elements of `vec` to width `max_width`.
 #'
 #' @keywords internal
-setGeneric("vec_nlines", function(vec, max_width = NULL, fontspec = dflt_courier, round_type = c("iec", "sas")) {
+setGeneric("vec_nlines", function(vec, max_width = NULL, fontspec = dflt_courier, round_type = valid_round_type) {
   standardGeneric("vec_nlines")
 })
 
@@ -116,7 +122,7 @@ setGeneric("vec_nlines", function(vec, max_width = NULL, fontspec = dflt_courier
 #'
 #' @rdname vec_nlines
 #' @keywords internal
-setMethod("vec_nlines", "ANY", function(vec, max_width = NULL, fontspec = dflt_courier, round_type = c("iec", "sas")) {
+setMethod("vec_nlines", "ANY", function(vec, max_width = NULL, fontspec = dflt_courier, round_type = valid_round_type) {
   round_type <- match.arg(round_type)
   if (is.null(max_width)) {
     max_width <- floor(0.9 * getOption("width")) # default of base::strwrap
@@ -141,7 +147,6 @@ setMethod("vec_nlines", "ANY", function(vec, max_width = NULL, fontspec = dflt_c
 ## })
 
 
-
 #' Make pagination data frame for a listing
 #'
 #' @inheritParams formatters::make_row_df
@@ -170,7 +175,11 @@ setMethod(
            sibpos = NA_integer_,
            nsibs = NA_integer_,
            fontspec = dflt_courier,
-           round_type = c("iec", "sas")) {
+           round_type = obj_round_type(tt)) {
+    new_dev <- open_font_dev(fontspec)
+    if (new_dev) {
+      on.exit(close_font_dev())
+    }
     ## assume sortedness by keycols
     keycols <- get_keycols(tt)
     dispcols <- listing_dispcols(tt)
@@ -180,7 +189,7 @@ setMethod(
     } else {
       runlens <- rep(1, NROW(tt))
     }
-    sibpos <- unlist(lapply(runlens, seq_len))
+    sibpos <- sequence(runlens)
     nsibs <- rep(runlens, times = runlens)
     extents <- rep(1L, nrow(tt))
     if (length(colwidths) > 0 && length(colwidths) != length(dispcols)) {
@@ -397,3 +406,23 @@ setMethod(
     length(get_keycols(obj))
   }
 )
+#### obj_round_type getter-----
+#' @rdname listing_methods
+#' @export
+setMethod(
+  "obj_round_type", "listing_df",
+  function(obj) {
+    attr(obj, "round_type")
+  }
+)
+#### obj_round_type setter -----
+#' @rdname listing_methods
+#' @export
+setMethod(
+  "obj_round_type<-", "listing_df",
+  function(obj, value) {
+    match.arg(value, valid_round_type)
+    attr(obj, "round_type") <- value
+    obj
+  }
+)
