@@ -1,6 +1,6 @@
 testthat::test_that("Column labels are the same", {
   ## listings var labels don't get mucked up by topleft machinery #262
-  lsting <- as_listing(anl, key_cols = c("USUBJID")) %>%
+  lsting <- as_listing(anl, key_cols = c("USUBJID")) |>
     add_listing_col("ARM")
 
   testthat::expect_identical(var_labels(anl), var_labels(lsting))
@@ -23,9 +23,9 @@ testthat::test_that("listings work well with different formats and attributes",
   var_labels(anl_tmp) <- var_labels(ex_adsl)[c("USUBJID", "ARM", "BMRKR1")]
   anl_tmp$BMRKR1[1:3] <- NA
 
-  lsting <- as_listing(anl_tmp, key_cols = c("ARM", "USUBJID")) %>%
-    add_listing_col("ARM") %>%
-    add_listing_col("USUBJID") %>%
+  lsting <- as_listing(anl_tmp, key_cols = c("ARM", "USUBJID")) |>
+    add_listing_col("ARM") |>
+    add_listing_col("USUBJID") |>
     add_listing_col("BMRKR1", format = "xx.xx")
 
   main_title(lsting) <- "main title"
@@ -373,7 +373,7 @@ testthat::test_that("add_listing_col works with a function when a format is appl
     mtcars[1:5, ],
     key_cols = c("gear", "carb"),
     disp_cols = "qsec"
-  ) %>%
+  ) |>
     add_listing_col(
       "kpg",
       function(df) df$mpg * 1.60934,
@@ -395,7 +395,7 @@ testthat::test_that("split_into_pages_by_var works as expected", {
     disp_cols = "SEX",
     main_title = "title",
     main_footer = "foot"
-  ) %>%
+  ) |>
     split_into_pages_by_var("SEX", page_prefix = "Patient Subset - Sex")
 
   testthat::expect_equal(length(lsting), length(unique(tmp_data[["SEX"]])))
@@ -407,7 +407,7 @@ testthat::test_that("split_into_pages_by_var works as expected", {
     disp_cols = "SEX",
     main_title = "title",
     main_footer = "foot"
-  ) %>%
+  ) |>
     split_into_pages_by_var("SEX")
   lsting_id <- as_listing(
     tmp_data,
@@ -430,6 +430,119 @@ testthat::test_that("appropriate error message returned for 'difftime' class", {
     disp_cols = "study_duration_secs",
     main_title = "title",
     main_footer = "foot"
-  ) %>%
+  ) |>
     split_into_pages_by_var("SEX", page_prefix = "Patient Subset - Sex"))
 })
+
+
+testthat::test_that("round_type approach works", {
+  vals <- c(1.865)
+
+  txtvals_iec <- mapply(format_value, x = vals, format = "xx.xx", round_type = "iec")
+  txtvals_sas <- mapply(format_value, x = vals, format = "xx.xx", round_type = "sas")
+
+  # adjust vals if following is not TRUE
+  expect_true(any(txtvals_iec != txtvals_sas))
+
+  anl <- ex_adsl
+  anl <- anl[1:10, c("USUBJID", "ARM", "BMRKR1")]
+
+  lsting <- as_listing(anl, key_cols = c("ARM", "USUBJID")) |>
+    add_listing_col("ARM") |>
+    add_listing_col("USUBJID") |>
+    add_listing_col("BMRKR1", format = "xx.xx")
+
+  # update a single value from listing to vals, to demonstrate sas rounding
+  lsting$BMRKR1[2] <- vals
+
+  mat <- matrix_form(lsting)
+
+  testthat::expect_identical(
+    unname(mat$strings[3, 3, drop = TRUE]),
+    txtvals_iec
+  )
+
+  # approach 1 to use sas rounding, through resetting obj_round_type of class listing_df
+  lsting_sas <- lsting
+  obj_round_type(lsting_sas) <- "sas"
+  mat_sas <- matrix_form(lsting_sas)
+
+  testthat::expect_identical(
+    unname(mat_sas$strings[3, 3, drop = TRUE]),
+    txtvals_sas
+  )
+
+  # approach 2 to use sas rounding, through call to matrix_form with updated round_type
+  mat_sas2 <- matrix_form(lsting, round_type = "sas")
+
+  testthat::expect_identical(
+    unname(mat_sas2$strings[3, 3, drop = TRUE]),
+    txtvals_sas
+  )
+})
+
+
+testthat::test_that("round_type getter and setter on list of listing_df", {
+  tmp_data <- ex_adae[1:100, ]
+  new_BMRKR1_val <- 1.865
+  fmtvalsas <- format_value(new_BMRKR1_val, format = "xx.xx", round_type = "sas")
+  fmtvaliec <- format_value(new_BMRKR1_val, format = "xx.xx", round_type = "iec")
+  expect_true(fmtvalsas != fmtvaliec)
+
+  subj1 <- head(tmp_data[tmp_data$"SEX" == "F", "SUBJID", drop = TRUE], 1)
+  subj2 <- head(tmp_data[tmp_data$"SEX" == "M", "SUBJID", drop = TRUE], 1)
+  tmp_data[tmp_data$SUBJID == subj1, "BMRKR1"] <- new_BMRKR1_val
+  tmp_data[tmp_data$SUBJID == subj2, "BMRKR1"] <- new_BMRKR1_val
+
+  lsting <- as_listing(
+    tmp_data,
+    key_cols = c("USUBJID", "AGE"),
+    disp_cols = c("SEX", "BMRKR1"),
+    col_formatting = c("BMRKR1" = fmt_config(format = "xx.xx")),
+    main_title = "title",
+    main_footer = "foot"
+  ) |>
+    split_into_pages_by_var("SEX", page_prefix = "Patient Subset - Sex")
+
+  # round_type getter to retrieve info from list of listing_df
+  testthat::expect_identical(
+    obj_round_type(lsting),
+    "iec"
+  )
+
+  # round_type setter to modify on list of listing_df into sas
+  obj_round_type(lsting) <- "sas"
+  testthat::expect_identical(
+    obj_round_type(lsting),
+    "sas"
+  )
+
+  ## setting round type on a list sets it on each of the list elements
+  testthat::expect_true(
+    all(vapply(lsting, obj_round_type, "") == "sas")
+  )
+
+  # check that round_type update actually has occurred on values
+  lsting1 <- lsting[[1]]
+  lsting2 <- lsting[[2]]
+
+  checksubj1 <- lsting1[lsting1$"SUBJID" == subj1, ]
+  checksubj2 <- lsting2[lsting2$"SUBJID" == subj2, ]
+  BMRKR1_subj1 <- matrix_form(checksubj1)$strings[2, "BMRKR1"]
+  BMRKR1_subj2 <- matrix_form(checksubj2)$strings[2, "BMRKR1"]
+
+
+  testthat::expect_identical(
+    unname(BMRKR1_subj1),
+    format_value(new_BMRKR1_val, format = "xx.xx", round_type = "sas")
+  )
+
+  testthat::expect_identical(
+    unname(BMRKR1_subj2),
+    format_value(new_BMRKR1_val, format = "xx.xx", round_type = "sas")
+  )
+
+  expect_error({
+    obj_round_type(lsting) <- "not real"
+  })
+})
